@@ -2,7 +2,7 @@
 * string.cpp: Strings manipulation
 *-------------------------------------------------------------------------------
 * (c)1999-2001 VideoLAN
-* $Id: string.cpp,v 1.2 2002/03/04 01:55:49 bozo Exp $
+* $Id: string.cpp,v 1.4 2002/11/11 09:51:00 nitrox Exp $
 *
 * Authors: Benoit Steiner <benny@via.ecp.fr>
 *
@@ -583,7 +583,25 @@ int C_String::Find(char cChar, unsigned int iStart) const
   return GEN_ERR;
 }
 
-
+//------------------------------------------------------------------------------
+// 
+//------------------------------------------------------------------------------
+// Replace all occurences of the char returns number of occurences
+//------------------------------------------------------------------------------
+int C_String::Replace(char cChar, char cChar2, unsigned int iStart) 
+{
+  int count=0;
+  for(unsigned int i = iStart; i < m_iLength; i++)
+  {
+    if(m_pszBuff[i] == cChar)
+    {
+      m_pszBuff[i] = cChar2;
+      count++;
+    }
+  }
+  
+  return count;
+}
 //------------------------------------------------------------------------------
 // 
 //------------------------------------------------------------------------------
@@ -618,11 +636,8 @@ int C_String::Find(const C_String& strItem, unsigned int iStart/* = 0*/) const
           break;
         }
       }
-      else
-      {
-        // First char of the item not found: look further in the string
-        pCurrentChar++;
-      }
+      // First char of the item not found: look further in the string
+      pCurrentChar++;
     }
   }
   
