@@ -2,7 +2,7 @@
 * output.h: output stream classes definitions
 *-------------------------------------------------------------------------------
 * (c)1999-2001 VideoLAN
-* $Id: output.h,v 1.3 2001/11/22 01:51:12 bozo Exp $
+* $Id: output.h,v 1.4 2002/08/09 13:42:32 tooney Exp $
 *
 * Authors: Benoit Steiner <benny@via.ecp.fr>
 *          Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
@@ -61,7 +61,7 @@ class C_Output
   void Init(C_NetList* pTsProvider);
   void Close();
 
-  void Send(C_TsPacket* pPacket);
+  void Send(C_TsPacket* pPacket,bool RtpEncapsulation);
   void Flush();
 
   // Return the capacity of the output buffer
@@ -71,9 +71,11 @@ class C_Output
   // Return the number of byte lost
   unsigned int GetByteLoss()
   { return m_iByteLost; }
-  
+
+  inline s64 GetDate();
+
  protected:
-  virtual void WriteToPort() = 0;
+  virtual void WriteToPort(bool RtpEncapsulation, u32 RtpSendTime) = 0;
   virtual void OnInit() = 0;
   virtual void OnClose() = 0;
 
@@ -85,6 +87,10 @@ class C_Output
 
   // Byte loss counter
   unsigned int m_iByteLost;
+
+  C_RtpHeader * m_pRtpHeader;
+  u16 m_iRtpCounter;
+
 };
 
 
